@@ -168,7 +168,7 @@ void Model::initialize(bool datagen)
 	for (unsigned int ch = 0; ch < _nchain; ++ch) {
 	    for (unsigned int i = 0; i < _stochastic_nodes.size(); ++i) {
 		StochasticNode const *snode = _stochastic_nodes[i];
-		double ld = snode->logDensity(ch);
+		double ld = snode->logDensity(ch, PDF_PRIOR);
 		if (jags_isnan(ld)) {
 		    string msg = "Error calculating log density at initial values";
 		    throw NodeError(snode, msg);
@@ -413,19 +413,24 @@ unsigned int Model::iteration() const
   return _iteration;
 }
 
-bool Model::adaptOff() 
+void Model::adaptOff() 
 {
-    bool status = true;
-
-    for (vector<Sampler*>::iterator p = _samplers.begin(); 
+    for (vector<Sampler*>::const_iterator p = _samplers.begin(); 
 	 p != _samplers.end(); ++p)
     {
-	if (!(*p)->adaptOff())
-	    status = false;
+	(*p)->adaptOff();
     }
-
     _adapt = false;
-    return status;
+}
+
+bool Model::checkAdaptation() const
+{
+    for (vector<Sampler*>::const_iterator p = _samplers.begin(); 
+	 p != _samplers.end(); ++p)
+    {
+	if (!(*p)->checkAdaptation()) return false;
+    }
+    return true;
 }
 
 bool Model::isAdapting() const
@@ -486,7 +491,7 @@ void Model::setSampledExtra()
 void Model::addMonitor(Monitor *monitor, unsigned int thin)
 {
     if (_adapt) {
-	throw logic_error("Cannot add monitor to adapting model");
+	throw runtime_error("Turn off adaptive mode before setting monitors");
     }
     
     _monitors.push_back(MonitorControl(monitor, _iteration+1, thin));
