@@ -18,11 +18,13 @@ class Divide:public Infix
 {
 public:
     Divide ();
-    double evaluateScalar(std::vector<double const *> const &args) const;
-    bool checkScalarValue (std::vector <double const *> const &args) const;
-    bool isLinear(std::vector<bool> const &mask,
-		  std::vector<bool> const &fixmask) const;
-    bool isScale(unsigned int index, std::vector<bool> const &fixmask) const;
+    double evaluate(std::vector<double const *> const &args) const;
+    bool checkParameterValue (std::vector <double const *> const &args) const;
+    bool isScale(std::vector<bool> const &mask,
+                 std::vector<bool> const &fix) const;
+    bool isPower(std::vector<bool> const &mask,
+                 std::vector<bool> const &fix) const;
+
 };
 
 }
