@@ -3,6 +3,8 @@
 
 #include "RScalarDist.h"
 
+namespace bugs {
+
 /**
  * @short Beta distribution
  * <pre>
@@ -14,7 +16,8 @@ class DBeta : public RScalarDist {
  public:
   DBeta();
 
-  double d(double x, std::vector<double const *> const &parameters, 
+  double d(double x, PDFType type,
+	   std::vector<double const *> const &parameters, 
 	   bool give_log) const;
   double p(double q, std::vector<double const *> const &parameters, bool lower,
 	   bool give_log) const;
@@ -25,7 +28,10 @@ class DBeta : public RScalarDist {
    * Checks that a > 0, b > 0
    */
   bool checkParameterValue(std::vector<double const *> const &parameters) const;
-
+  double KL(std::vector<double const *> const &par1, 
+	    std::vector<double const *> const &par2) const;
 };
 
+}
+
 #endif /* DBETA_H_ */
