@@ -5,6 +5,7 @@
 
 using std::vector;
 using std::acos;
+using std::string;
 
 namespace bugs {
 
@@ -12,6 +13,11 @@ namespace bugs {
 	: ScalarFunction ("arccos", 1)
     {
     }
+
+    string ArcCos::alias() const
+    {
+	return "acos";
+    }
     
     double ArcCos::evaluate(vector<double const *> const &args) const
     {
