@@ -22,8 +22,7 @@ namespace bugs {
 	return *args[0] >= 0;
     }
 
-    bool Sqrt::isPower(std::vector<bool> const &mask,
-                       std::vector<bool> const &fix) const
+    bool Sqrt::isPower(vector<bool> const &mask, vector<bool> const &fix) const
     {
         return true;
     }
