@@ -3,6 +3,8 @@
 
 #include <sampler/SingletonFactory.h>
 
+namespace bugs {
+
 /**
  * @short Factory object for conjugate samplers
  */
@@ -23,4 +25,6 @@ public:
     std::string name() const;
 };
 
+}
+
 #endif /* CONJUGATE_FACTORY_H_ */
