@@ -16,6 +16,10 @@ namespace glm {
 	BinaryGLM *newBinary(GraphView const *view, 
 			     std::vector<GraphView const *> const &sub_views,
 			     unsigned int chain) const;
+	/**
+	 * Holmes-Held method requires a fixed design matrix
+	 */
+	bool fixedGLM() const;
     };
 
 }
