@@ -18,11 +18,10 @@ class DMState : public ArrayDist {
 public:
     DMState();
   
-    double logLikelihood(double const *x, unsigned int length,
-			 std::vector<double const *> const &parameters,
-			 std::vector<std::vector<unsigned int> > const &dims,
-			 double const *lower, double const *upper)
-	const;
+    double logDensity(double const *x, unsigned int length, PDFType type,
+		      std::vector<double const *> const &parameters,
+		      std::vector<std::vector<unsigned int> > const &dims,
+		      double const *lower, double const *upper)	const;
     void randomSample(double *x, unsigned int length,
 		      std::vector<double const *> const &parameters,
 		      std::vector<std::vector<unsigned int> > const &dims,
